.. image:: https://travis-ci.org/wireservice/agate-lookup.png
    :target: https://travis-ci.org/wireservice/agate-lookup
    :alt: Build status

.. image:: https://img.shields.io/pypi/dw/agate-lookup.svg
    :target: https://pypi.python.org/pypi/agate-lookup
    :alt: PyPI downloads

.. image:: https://img.shields.io/pypi/v/agate-lookup.svg
    :target: https://pypi.python.org/pypi/agate-lookup
    :alt: Version

.. image:: https://img.shields.io/pypi/l/agate-lookup.svg
    :target: https://pypi.python.org/pypi/agate-lookup
    :alt: License

.. image:: https://img.shields.io/pypi/pyversions/agate-lookup.svg
    :target: https://pypi.python.org/pypi/agate-lookup
    :alt: Support Python versions

agate-lookup adds remote lookup tables to `agate <https://github.com/onyxfish/agate>`_.

Important links:

* agate             http://agate.rtfd.org
* Documentation:    http://agate-lookup.rtfd.org
* Repository:       https://github.com/wireservice/agate-lookup
* Issues:           https://github.com/wireservice/agate-lookup/issues
